@@ -9,12 +9,13 @@ import sys
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
 
 try:
+    import utils.exceptions as exceptions
     import mysql.connector as mc
     import tabulate
     import packages.auth as auth
 
 except:
-    raise Exception("'ddl_commands' module not setup")
+    raise exceptions.ModuleSetupError("ddl_commands")
 
 
 class DDL:
@@ -86,7 +87,7 @@ class DDL:
             self.cursor = self.connection.cursor(buffered = True)
 
         else:
-            raise Exception("User could not be authenticated")
+            raise exceptions.AuthenticationError()
 
     def show_databases(self):
         """
